@@ -7,10 +7,13 @@ from tempfile import mkdtemp
 import time
 import osso
 import gobject
+import cairo
 
 import import_data
 import db
 
+from cairo_widget import Screen
+
 BEEP = "/usr/share/roadrunner/beep.wav"
 ABOUT_MESSAGE = """Roadrunner alerts You about speed cameras on the road.
 Local import supports GPX, KML, KMZ, CSV and ASC formats.
@@ -23,6 +26,8 @@ class  roadrunnerApp(hildon.Program):
     def __init__(self):
         """Contains main methods for the app class"""
         
+        self.i=9999
+        
         hildon.Program.__init__(self)
         
         self.previousfixtime = float("nan")
@@ -60,7 +65,7 @@ class  roadrunnerApp(hildon.Program):
         self.odevice = osso.DeviceState(self.osso_c)
         
         # Only in Scratchbox
-        #gobject.timeout_add(3000, self.test_alert)        
+        #gobject.timeout_add(500, self.test_alert)        
 
         self.window = hildon.StackableWindow()
         self.add_window(self.window)
@@ -75,6 +80,7 @@ class  roadrunnerApp(hildon.Program):
         self.window.connect("delete_event", self.quit, self.control)
 
         self.build_window_alert()
+        self.prepare_alert()
         gtk.main()        
         
         
@@ -264,10 +270,10 @@ class  roadrunnerApp(hildon.Program):
         """Build the menu"""
         
         menu = hildon.AppMenu()
-        button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
-        button.set_label("Download speed cameras...")
-        button.connect("clicked", self.imp_asc, None)
-        menu.append(button)
+        #button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+        #button.set_label("Download speed cameras...")
+        #button.connect("clicked", self.imp_asc, None)
+        #menu.append(button)
         button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
         button.set_label("Import local file...")
         button.connect("clicked", self.imp_file, None)
@@ -368,8 +374,8 @@ class  roadrunnerApp(hildon.Program):
                             val = rdistance * 1000 / 0.3048
                         else:
                             val = rdistance * 1000
-                        self.alert_label.set_markup("<span size='250000'><b>%.0f</b></span>" % (val))
-                        self.start_alert()
+                        #self.alert_label.set_markup("<span size='250000'><b>%.0f</b></span>" % (val))
+                        self.start_alert("%.0f" % (val))
                         pass
                     else:
                         self.stop_alert()
@@ -437,8 +443,26 @@ class  roadrunnerApp(hildon.Program):
         self.alert_window.set_transient_for(self.window)
         
         
-    def start_alert(self):        
+    def prepare_alert(self):
+        
+        self.window_alert = gtk.Window(gtk.WINDOW_POPUP)
+        self.window_alert .set_default_size(800, 480)
+        self.window_alert .connect("delete-event", gtk.main_quit)
+        self.widget = Screen()
+        #self.widget.show()
+        self.window_alert .add(self.widget)
+        #self.window_alert.present()
+        self.window_alert .set_default_size(800, 480)
+      
+        
+    def start_alert(self,  distance=0):        
         """activate the alert"""
+        print 'Refresh'
+        self.widget.distance = distance
+        print self.widget.distance
+        self.widget.show_all()
+        self.window_alert.present()
+        self.window_alert.show_all()
         
         if self.alert == False:
             print "start alert"
@@ -452,7 +476,8 @@ class  roadrunnerApp(hildon.Program):
             if self.sound == 'True':
                 gobject.timeout_add(2000, self.activate_beep)
             self.alert = True
-            self.alert_window.show_all()
+            #self.alert_window.show_all()
+            self.window_alert.show_all()
         
         
     def stop_alert(self):
@@ -461,7 +486,7 @@ class  roadrunnerApp(hildon.Program):
         if self.alert == True:
             print "stop alert"
             self.alert = False
-            self.alert_window.hide_all()
+            self.window_alert.hide_all()
             
     
     def keep_display_on(self):
@@ -496,8 +521,9 @@ class  roadrunnerApp(hildon.Program):
     
     def test_alert(self):
         print "test_alert"
+        self.i += 1
         if os.path.isfile("zz"):
-            self.start_alert()
+            self.start_alert(str(self.i))
         else:
             self.stop_alert()
         return True
